@@ -1,7 +1,6 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,6 +17,9 @@
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA  02110-1301, USA.
  */
+
+#include "config.h"
+
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
@@ -27,8 +29,10 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/statvfs.h>
+#include <sys/file.h>
 #include <fcntl.h>
 #include <limits.h>
+#include <errno.h>
 
 #include <glib.h>
 #include <gio/gio.h>
@@ -40,12 +44,14 @@
 
 #define TEXT_SNIFF_SIZE 4096
 
+static GHashTable *file_locks = NULL;
+
 FILE *
 tracker_file_open (const gchar *uri,
-		   const gchar *how,
-		   gboolean	sequential)
+                   const gchar *how,
+                   gboolean     sequential)
 {
- 	FILE     *file;
+	FILE     *file;
 	gboolean  readonly;
 	int       flags;
 
@@ -57,14 +63,14 @@ tracker_file_open (const gchar *uri,
 		return NULL;
 	}
 
- 	/* Are we opening for readonly? */
+	/* Are we opening for readonly? */
 	readonly = !strstr (uri, "r+") && strchr (uri, 'r');
 
 	if (readonly) {
 		int fd;
 
 		fd = fileno (file);
-		
+
 #if defined(__linux__)
 		/* Make sure we set the NOATIME flag if we have permissions to */
 		if ((flags = fcntl (fd, F_GETFL, 0)) != -1) {
@@ -72,13 +78,13 @@ tracker_file_open (const gchar *uri,
 		}
 #endif
 	}
-	
+
 	return file;
 }
 
 void
 tracker_file_close (FILE     *file,
-		    gboolean  need_again_soon) 
+                    gboolean  need_again_soon)
 {
 	g_return_if_fail (file != NULL);
 
@@ -89,23 +95,23 @@ goffset
 tracker_file_get_size (const gchar *path)
 {
 	GFileInfo *info;
-	GFile	  *file;
-	GError	  *error = NULL;
+	GFile     *file;
+	GError    *error = NULL;
 	goffset    size;
 
 	g_return_val_if_fail (path != NULL, 0);
 
 	file = g_file_new_for_path (path);
 	info = g_file_query_info (file,
-				  G_FILE_ATTRIBUTE_STANDARD_SIZE,
-				  G_FILE_QUERY_INFO_NONE,
-				  NULL,
-				  &error);
+	                          G_FILE_ATTRIBUTE_STANDARD_SIZE,
+	                          G_FILE_QUERY_INFO_NONE,
+	                          NULL,
+	                          &error);
 
 	if (G_UNLIKELY (error)) {
 		g_message ("Could not get size for '%s', %s",
-			   path,
-			   error->message);
+		           path,
+		           error->message);
 		g_error_free (error);
 		size = 0;
 	} else {
@@ -122,23 +128,23 @@ guint64
 tracker_file_get_mtime (const gchar *path)
 {
 	GFileInfo *info;
-	GFile	  *file;
-	GError	  *error = NULL;
+	GFile     *file;
+	GError    *error = NULL;
 	guint64    mtime;
 
 	g_return_val_if_fail (path != NULL, 0);
 
 	file = g_file_new_for_path (path);
 	info = g_file_query_info (file,
-				  G_FILE_ATTRIBUTE_TIME_MODIFIED,
-				  G_FILE_QUERY_INFO_NONE,
-				  NULL,
-				  &error);
+	                          G_FILE_ATTRIBUTE_TIME_MODIFIED,
+	                          G_FILE_QUERY_INFO_NONE,
+	                          NULL,
+	                          &error);
 
 	if (G_UNLIKELY (error)) {
 		g_message ("Could not get mtime for '%s', %s",
-			   path,
-			   error->message);
+		           path,
+		           error->message);
 		g_error_free (error);
 		mtime = 0;
 	} else {
@@ -155,20 +161,20 @@ gchar *
 tracker_file_get_mime_type (GFile *file)
 {
 	GFileInfo *info;
-	GError	  *error = NULL;
-	gchar	  *content_type;
+	GError    *error = NULL;
+	gchar     *content_type;
 
 	g_return_val_if_fail (G_IS_FILE (file), NULL);
 
 	info = g_file_query_info (file,
-				  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
-				  G_FILE_QUERY_INFO_NONE,
-				  NULL,
-				  &error);
+	                          G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+	                          G_FILE_QUERY_INFO_NONE,
+	                          NULL,
+	                          &error);
 
 	if (G_UNLIKELY (error)) {
 		g_message ("Could not guess mimetype, %s",
-			   error->message);
+		           error->message);
 		g_error_free (error);
 		content_type = NULL;
 	} else {
@@ -181,7 +187,7 @@ tracker_file_get_mime_type (GFile *file)
 
 gboolean
 tracker_file_system_has_enough_space (const gchar *path,
-				      gulong       required_bytes)
+                                      gulong       required_bytes)
 {
 	struct statvfs st;
 	gchar *str1;
@@ -202,14 +208,14 @@ tracker_file_system_has_enough_space (const gchar *path,
 
 	if (!enough) {
 		g_critical ("Not enough disk space to create databases, "
-			    "%s remaining, %s required as a minimum",
-			    str2,
-			    str1);
+		            "%s remaining, %s required as a minimum",
+		            str2,
+		            str1);
 	} else {
 		g_message ("Checking for adequate disk space to create databases, "
-			   "%s remaining, %s required as a minimum",
-			   str2,
-			   str1);
+		           "%s remaining, %s required as a minimum",
+		           str2,
+		           str1);
 	}
 
 	g_free (str2);
@@ -267,10 +273,10 @@ tracker_path_remove (const gchar *path)
 
 gboolean
 tracker_path_is_in_path (const gchar *path,
-			 const gchar *in_path)
+                         const gchar *in_path)
 {
-	gchar	 *new_path;
-	gchar	 *new_in_path;
+	gchar    *new_path;
+	gchar    *new_in_path;
 	gboolean  is_in_path = FALSE;
 
 	g_return_val_if_fail (path != NULL, FALSE);
@@ -323,14 +329,14 @@ tracker_path_hash_table_filter_duplicates (GHashTable *roots)
 
 			if (tracker_path_is_in_path (path, in_path)) {
 				g_debug ("Removing path:'%s', it is in path:'%s'",
-					 path, in_path);
+				         path, in_path);
 
 				g_hash_table_iter_remove (&iter1);
 				g_hash_table_iter_init (&iter1, roots);
 				break;
 			} else if (tracker_path_is_in_path (in_path, path)) {
 				g_debug ("Removing path:'%s', it is in path:'%s'",
-					 in_path, path);
+				         in_path, path);
 
 				g_hash_table_iter_remove (&iter2);
 				g_hash_table_iter_init (&iter1, roots);
@@ -338,7 +344,7 @@ tracker_path_hash_table_filter_duplicates (GHashTable *roots)
 			}
 		}
 
-		/* Make sure the path doesn't have the '/' suffix. */	
+		/* Make sure the path doesn't have the '/' suffix. */
 		p = strrchr (path, G_DIR_SEPARATOR);
 
 		if (p) {
@@ -367,7 +373,7 @@ tracker_path_hash_table_filter_duplicates (GHashTable *roots)
 
 GSList *
 tracker_path_list_filter_duplicates (GSList      *roots,
-				     const gchar *basename_exception_prefix)
+                                     const gchar *basename_exception_prefix)
 {
 	GSList *l1, *l2;
 	GSList *new_list;
@@ -388,12 +394,12 @@ tracker_path_list_filter_duplicates (GSList      *roots,
 			const gchar *in_path;
 
 			in_path = l2->data;
-			
+
 			if (path == in_path) {
 				/* Do nothing */
 				l2 = l2->next;
 				continue;
-			} 
+			}
 
 			if (basename_exception_prefix) {
 				gchar *lbasename;
@@ -402,11 +408,11 @@ tracker_path_list_filter_duplicates (GSList      *roots,
 				lbasename = g_path_get_basename (path);
 				if (!g_str_has_prefix (lbasename, basename_exception_prefix)) {
 					g_free (lbasename);
-					
+
 					lbasename = g_path_get_basename (in_path);
 					if (g_str_has_prefix (lbasename, basename_exception_prefix)) {
 						has_prefix = TRUE;
-					}	
+					}
 				} else {
 					has_prefix = TRUE;
 				}
@@ -424,7 +430,7 @@ tracker_path_list_filter_duplicates (GSList      *roots,
 
 			if (tracker_path_is_in_path (path, in_path)) {
 				g_debug ("Removing path:'%s', it is in path:'%s'",
-					 path, in_path);
+				         path, in_path);
 
 				g_free (l1->data);
 				new_list = g_slist_delete_link (new_list, l1);
@@ -433,11 +439,11 @@ tracker_path_list_filter_duplicates (GSList      *roots,
 				reset = TRUE;
 
 				continue;
-			} 
+			}
 			else if (tracker_path_is_in_path (in_path, path)) {
 				g_debug ("Removing path:'%s', it is in path:'%s'",
-					 in_path, path);
-				
+				         in_path, path);
+
 				g_free (l2->data);
 				new_list = g_slist_delete_link (new_list, l2);
 				l1 = new_list;
@@ -449,8 +455,8 @@ tracker_path_list_filter_duplicates (GSList      *roots,
 
 			l2 = l2->next;
 		}
-		
-		/* Make sure the path doesn't have the '/' suffix. */	
+
+		/* Make sure the path doesn't have the '/' suffix. */
 		p = strrchr (path, G_DIR_SEPARATOR);
 
 		if (p) {
@@ -459,7 +465,7 @@ tracker_path_list_filter_duplicates (GSList      *roots,
 			}
 		}
 
-		/* Continue in list unless reset. */	
+		/* Continue in list unless reset. */
 		if (G_LIKELY (!reset)) {
 			l1 = l1->next;
 		}
@@ -483,13 +489,13 @@ tracker_path_list_filter_duplicates (GSList      *roots,
 gchar *
 tracker_path_evaluate_name (const gchar *path)
 {
-	gchar	     *final_path;
-	gchar	    **tokens;
-	gchar	    **token;
-	gchar	     *start;
-	gchar	     *end;
+	gchar        *final_path;
+	gchar       **tokens;
+	gchar       **token;
+	gchar        *start;
+	gchar        *end;
 	const gchar  *env;
-	gchar	     *expanded;
+	gchar        *expanded;
 
 	if (!path || path[0] == '\0') {
 		return NULL;
@@ -497,16 +503,21 @@ tracker_path_evaluate_name (const gchar *path)
 
 	/* First check the simple case of using tilder */
 	if (path[0] == '~') {
-		const char *home = g_get_home_dir ();
+		const gchar *home;
+
+		home = g_getenv ("HOME");
+		if (! home) {
+			home = g_get_home_dir ();
+		}
 
 		if (!home || home[0] == '\0') {
 			return NULL;
 		}
 
 		return g_build_path (G_DIR_SEPARATOR_S,
-				     home,
-				     path + 1,
-				     NULL);
+		                     home,
+		                     path + 1,
+		                     NULL);
 	}
 
 	/* Second try to find any environment variables and expand
@@ -566,11 +577,11 @@ tracker_path_evaluate_name (const gchar *path)
 
 static gboolean
 path_has_write_access (const gchar *path,
-		       gboolean    *exists)
+                       gboolean    *exists)
 {
-	GFile	  *file;
+	GFile     *file;
 	GFileInfo *info;
-	GError	  *error = NULL;
+	GError    *error = NULL;
 	gboolean   writable;
 
 	g_return_val_if_fail (path != NULL, FALSE);
@@ -578,10 +589,10 @@ path_has_write_access (const gchar *path,
 
 	file = g_file_new_for_path (path);
 	info = g_file_query_info (file,
-				  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
-				  0,
-				  NULL,
-				  &error);
+	                          G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
+	                          0,
+	                          NULL,
+	                          &error);
 	g_object_unref (file);
 
 	if (G_UNLIKELY (error)) {
@@ -591,9 +602,9 @@ path_has_write_access (const gchar *path,
 			}
 		} else {
 			g_warning ("Could not check if we have write access for "
-				   "path '%s', %s",
-				   path,
-				   error->message);
+			           "path '%s', %s",
+			           path,
+			           error->message);
 		}
 
 		g_error_free (error);
@@ -644,7 +655,7 @@ gboolean
 tracker_env_check_xdg_dirs (void)
 {
 	const gchar *user_data_dir;
-	gchar	    *new_dir;
+	gchar       *new_dir;
 	gboolean     success;
 
 	g_message ("Checking XDG_DATA_HOME is writable and exists");
@@ -679,3 +690,140 @@ tracker_env_check_xdg_dirs (void)
 
 	return success;
 }
+
+gboolean
+tracker_file_lock (GFile *file)
+{
+	gint fd, retval;
+	gchar *path;
+
+	g_return_val_if_fail (G_IS_FILE (file), FALSE);
+
+	if (G_UNLIKELY (!file_locks)) {
+		file_locks = g_hash_table_new_full ((GHashFunc) g_file_hash,
+		                                    (GEqualFunc) g_file_equal,
+		                                    (GDestroyNotify) g_object_unref,
+		                                    NULL);
+	}
+
+	/* Don't try to lock twice */
+	if (g_hash_table_lookup (file_locks, file) != NULL) {
+		return TRUE;
+	}
+
+	if (!g_file_is_native (file)) {
+		return FALSE;
+	}
+
+	path = g_file_get_path (file);
+
+	if (!path) {
+		return FALSE;
+	}
+
+	fd = open (path, O_RDONLY);
+
+	if (fd < 0) {
+		g_warning ("Could not open '%s'", path);
+		g_free (path);
+
+		return FALSE;
+	}
+
+	retval = flock (fd, LOCK_EX);
+
+	if (retval == 0) {
+		g_hash_table_insert (file_locks,
+		                     g_object_ref (file),
+		                     GINT_TO_POINTER (fd));
+	} else {
+		g_warning ("Could not lock file '%s'", path);
+		close (fd);
+	}
+
+	g_free (path);
+
+	return (retval == 0);
+}
+
+gboolean
+tracker_file_unlock (GFile *file)
+{
+	gint retval, fd;
+
+	g_return_val_if_fail (G_IS_FILE (file), TRUE);
+
+	if (!file_locks) {
+		return TRUE;
+	}
+
+	fd = GPOINTER_TO_INT (g_hash_table_lookup (file_locks, file));
+
+	if (fd == 0) {
+		/* File wasn't actually locked */
+		return TRUE;
+	}
+
+	retval = flock (fd, LOCK_UN);
+
+	if (retval < 0) {
+		gchar *path;
+
+		path = g_file_get_path (file);
+		g_warning ("Could not unlock file '%s'", path);
+		g_free (path);
+
+		return FALSE;
+	}
+
+	g_hash_table_remove (file_locks, file);
+	close (fd);
+
+	return TRUE;
+}
+
+gboolean
+tracker_file_is_locked (GFile *file)
+{
+	gboolean retval = FALSE;
+	gchar *path;
+	gint fd;
+
+	g_return_val_if_fail (G_IS_FILE (file), FALSE);
+
+	if (!g_file_is_native (file)) {
+		return FALSE;
+	}
+
+	path = g_file_get_path (file);
+
+	if (!path) {
+		return FALSE;
+	}
+
+	fd = open (path, O_RDONLY);
+
+	if (fd < 0) {
+		g_warning ("Could not open '%s'", path);
+		g_free (path);
+
+		return FALSE;
+	}
+
+	/* Check for locks */
+	retval = flock (fd, LOCK_SH | LOCK_NB);
+
+	if (retval < 0) {
+		if (errno == EWOULDBLOCK) {
+			retval = TRUE;
+		}
+	} else {
+		/* Oops, call was successful, unlock again the file */
+		flock (fd, LOCK_UN);
+	}
+
+	close (fd);
+	g_free (path);
+
+	return retval;
+}
